// components/selectImgs/selectImgs.js
const net = require("../../utils/net.js");
const util = require("../../utils/util.js");
const {
  api_upload_file,
  api_upload_del,
  api_image_scan,
} = require("../../utils/api.js");
Component({
  /**
   * 组件的属性列表
   */
  properties: {
    imgsArr: {
      type: Array,
      value: [],
      observer: function (newVal) {
        // 属性值变化时执行
        if (newVal && newVal.length) {
          this.setData({
            imgsList: newVal || [],
            count: newVal.length,
          });
        }
      },
    },
    maxCount: {
      type: Number,
      value: 9,
    },
    maxSize: {
      type: Number,
      value: 10,
    },
  },

  /**
   * 组件的初始数据
   */
  data: {
    imgsListObj: [],
    imgsList: [],
    count: 0,
    imgsUrl: [],
  },

  /**
   * 组件的方法列表
   */
  methods: {
    tapRemoveAction(e) {
      const { imgsList, imgsUrl, imgsListObj } = this.data;
      const { currentIndex } = e.currentTarget.dataset;
      imgsList.splice(currentIndex, 1);
      imgsListObj.splice(currentIndex, 1);
      imgsUrl.splice(currentIndex, 1);
      this.setData({
        imgsListObj: imgsListObj,
      });
      if (imgsUrl[currentIndex] && imgsUrl[currentIndex].length) {
        const delobj = imgsUrl.splice(currentIndex, 1);
        this.deleteImage(delobj.src);
      }
      this.triggerEvent("imgs", { imgs: imgsUrl });
    },
    tapAddImgAction() {
      const _this = this;
      wx.showActionSheet({
        itemList: ["从相册中", "拍照"],
        success(res) {
          if (res.tapIndex == 0) {
            _this.chooseImage("album");
          } else {
            _this.chooseImage("camera");
          }
        },
      });
    },
    chooseImage(type) {
      const _this = this;
      const { imgsList, maxSize, imgsUrl, imgsListObj } = this.data;
      let index = imgsList.length;
      wx.chooseImage({
        count: this.properties.maxCount - imgsListObj.length,
        sizeType: ["compressed"],
        sourceType: [type],
        success(res) {
          // tempFilePath可以作为img标签的src属性显示图片
          const { size } = res.tempFiles;
          if (size / 1024 > maxSize) {
            util.showToast({ title: "选择的图片文件过大,请您从新选择.." });
          } else {
            const files = res.tempFilePaths;
            for (let i = 0, n = files.length; i < n; i++) {
              const src = files[i];
              imgsListObj.push({ type: 1, src: src });
              _this.uploadImage(src, index + i);
              imgsList.push(src);
              imgsUrl.push({ type: 1, src: src });
            }
            _this.setData({
              imgsListObj: imgsListObj,
            });
            _this.triggerEvent("imgs", { imgs: imgsUrl });
          }
        },
      });
    },
    uploadImage(filePath, index) {
      const { imgsUrl, imgsList } = this.data;
      let params = {};
      params.url = api_upload_file;
      params.filePath = filePath;
      params.data = {
        project: "daily",
        contentType: "daily/project",
      };
      net.uploadFile(params).then((res) => {
        const { host, url } = res.data;
        if (Array.isArray(url) && url.length) {
          const imgSrc = host + url[0];
          const imgObj = imgsUrl[index];
          imgObj.src = imgSrc;
          imgsList.splice(index, 1, imgSrc);
          imgsUrl.splice(index, 1, imgObj);
          this.imageScan(imgSrc);
        }
      });
    },
    imageScan(url) {
      const { imgsList, imgsListObj, imgsUrl } = this.data;
      let params = {
        url: api_image_scan,
        data: {
          imgUrl: url,
        },
      };
      net.req(params).then((res) => {
        const { imgUrl, describe, status } = res;
        const index = imgsList.indexOf(imgUrl);
        if (index != -1) {
          const imgObj = imgsListObj[index];
          const obj = imgsUrl[index];
          if (parseInt(status) == 0) {
            imgObj.type = 3;
            obj.type = 3;
          } else {
            imgObj.type = 2;
            obj.type = 2;
            imgObj.describe = describe;
          }
          imgsUrl.splice(index, 1, obj);
          this.triggerEvent("imgs", { imgs: imgsUrl });
          this.setData({
            [`imgsListObj[${index}]`]: imgObj,
          });
        }
      });
    },

    deleteImage(url) {
      let params = {
        url: api_upload_del,
        data: {
          url: url,
          project: "daily/project",
        },
      };
      net.req(params).then();
    },
  },
});
