// 请注意常量的命名必须是Page
const {
  api_get_mobile_prefix,
  api_mobile_code,
  api_mobile_login,
} = require("../../utils/api.js");
const util = require("../../utils/util.js");
const net = require("../../utils/net.js");
Page({
  data: {
    isLoading: true,
    prefixArr: [],
    prefixIndex: 0,
    mobile: "",
    code: "",
    codeText: "获取验证码",
    btnCodeDisable: false,
    btnSureDisable: true,
    timer: null,
  },
  onLoad: function () {
    const prefixArr = util.getStorageSync("MOBILEPREFIXDATA");
    if (prefixArr) {
      prefixArr = JSON.parse(decodeURIComponent(prefixArr));
      this.setData(
        {
          prefixArr: prefixArr,
        },
        () => {
          this.selectPrefix86(prefixArr);
        }
      );
    } else {
      this.loadPrefix();
    }
  },
  onUnload: function () {
    let { timer } = this.data;
    if (timer) {
      clearTimeout(timer);
      timer = null;
    }
  },

  mobileChange: function (e) {
    let mobile = e.detail.value;
    this.data.mobile = mobile;
    let { code } = this.data;
    if (util.validator.checkMobile(mobile) && util.validator.checkCode(code)) {
      this.setData({
        btnSureDisable: false,
      });
    } else {
      this.setData({
        btnSureDisable: true,
      });
    }
  },
  codeChange: function (e) {
    let code = e.detail.value;
    this.data.code = code;
    let { mobile } = this.data;
    if (util.validator.checkMobile(mobile) && util.validator.checkCode(code)) {
      this.setData({
        btnSureDisable: false,
      });
    } else {
      this.setData({
        btnSureDisable: true,
      });
    }
  },
  handleSendCode: function (e) {
    let { mobile, prefixArr, prefixIndex } = this.data;
    if (!util.validator.checkMobile(mobile)) {
      util.showToast({ title: "请输入正确的手机号码" });
      return false;
    }
    let countryId = prefixArr[prefixIndex].id;
    this.sendSmsCode(countryId, mobile);
  },
  handleSure: function (e) {
    this.setData({
      btnSureDisable: true,
    });
    let { mobile, prefixArr, prefixIndex, code } = this.data;
    let countryId = prefixArr[prefixIndex].id;
    let params = {};
    params.url = api_mobile_login;
    params.data = {
      mobilePrefixId: countryId,
      mobile,
      verifyCode: code,
      hooid: "hooli_daily",
      loginType: 1,
    };

    const shareUid = util.getStorageSync("SHAREUID");
    if (shareUid && shareUid.length) {
      // 分享用户id
      params.data.shareUid = shareUid;
    }
    net
      .req(params, true)
      .then((data) => {
        this.setData({
          btnSureDisable: false,
        });
        if (data && data.userInfo && data.userInfo.token) {
          util.setStorageSync("USERINFO", data.userInfo);
          let pages = getCurrentPages(); /*在内存中的所有页面栈对象*/
          let reloadPage = pages[pages.length - 3]; /*我的页面对象*/
          if (reloadPage) {
            if (reloadPage.refreshCallback) reloadPage.refreshCallback();
            wx.navigateBack({
              delta: 2,
            });
          } else {
            wx.navigateBack({
              delta: 2,
            });
          }
          return false;
        }
      })
      .catch((e) => {
        this.setData({
          btnSureDisable: false,
        });
        util.showModal({
          title: "提示",
          content: e && e.msg,
          showCancel: false,
        });
      });
  },
  loadPrefix: function () {
    let params = {};
    params.data = {
      range: "B",
      prefix: "1",
    };
    params.url = api_get_mobile_prefix;
    net.req(params).then((res) => {
      if (res && Array.isArray(res) && res.length > 0) {
        let prefixArr = [];
        res.forEach((vvv, iii, aaa) => {
          let { list } = vvv;
          prefixArr = prefixArr.concat(list);
        });
        util.setStorageSync(
          "MOBILEPREFIXDATA",
          encodeURIComponent(JSON.stringify(prefixArr))
        );
        this.setData(
          {
            isLoading: false,
            prefixArr: prefixArr,
          },
          () => {
            this.selectPrefix86(prefixArr);
          }
        );
      }
    });
  },

  selectPrefix86(prefixArr) {
    for (let i = 0; i < prefixArr.length; i++) {
      let tmp = prefixArr[i];
      if (["86", "086", "+86", "+086"].indexOf(tmp.code) !== -1) {
        this.setData({
          prefixIndex: i,
        });
        break;
      }
    }
  },

  sendSmsCode: function (countryId, mobile) {
    let params = {};
    params.url = api_mobile_code;
    params.data = {
      mobilePrefixId: countryId,
      mobile: mobile,
      hooid: "hooli_daily",
      status: 5,
      senceId: 1,
    };
    net.req(params, true).then(
      (res) => {
        this.countDown();
      },
      (e) => {
        this.setData({
          btnCodeDisable: false,
        });
        let tips = "发送验证码失败";
        if (e) {
          let { msg } = e;
          if (msg && "fail" !== msg) {
            tips = msg;
          }
        }
        util.showToast({ title: tips });
      }
    );
    this.setData({
      btnCodeDisable: true,
    });
  },
  countDown: function () {
    /*短信验证码倒计时*/
    let timeCount = 60;
    let loop = () => {
      if (timeCount > 0) {
        this.setData({
          codeText: `重新获取（${timeCount}s）`,
        });
        timeCount--;
        this.data.timer = setTimeout(loop, 1000);
      } else {
        this.setData({
          codeText: `重新获取`,
          btnCodeDisable: false,
        });
        if (this.data.timer) {
          clearTimeout(this.data.timer);
          this.data.timer = null;
        }
      }
    };
    loop();
  },

  tapAreaCodeAction() {
    const { prefixArr, prefixIndex } = this.data;
    wx.navigateTo({
      url: "/pages/areaCode/areaCode?id=" + prefixArr[prefixIndex].id,
    });
  },
  areaCodeCallback(res) {
    if (res) {
      this.setData({
        prefixIndex: res.prefixIndex,
      });
    }
  },
});
