// pages/newDetail/newDetail.js
const net = require("../../utils/net.js");
const util = require("../../utils/util.js");
const {
  api_material_info,
  api_comment_list,
  api_comment_add,
  api_share_qrCode,
  api_comment_delete,
} = require("../../utils/api.js");
import Poster from "../../utils/poster.js";

Page({
  /**
   * 页面的初始数据
   */
  data: {
    newId: null,
    detailData: null,
    commentList: [],
    videoLoad: false,
    isFullScreen: false,
    page: 1,
    limit: 20,
    totalCount: 0,
    likeNum: 0,
    showInput: false,
    inputValue: "",
    replyName: "",
    isAuthor: false,
    isEmpty: false,

    template: null,
    postImgSrc: null,
    isShowQRPoster: false,
    isShowCanvas: false,
    isShowPostMask: false,
    extendObj: null,
    shareQRImgSrc: null,
    shareQRImgLoad: false,
    poster: null,
  },

  /**
   * 生命周期函数--监听页面加载
   */
  onLoad: function (options) {
    const { newId, shareUid, scene } = options;
    if (options && scene) {
      const parmasArr = scene.split("U"); // 通过U区分新闻id跟用户userCode
      if (Array.isArray(parmasArr)) {
        this.setData({
          newId: parmasArr[0],
        });
        this.loadNewDetailData(newId);
        if (parmasArr[1] && parmasArr[1].length) {
          const userCode = "U" + parmasArr[1]; // 拼接用户userCode
          util.setStorageSync("SHAREUID", userCode);
        }
      }
    } else if (options && newId) {
      this.setData({
        newId: newId,
      });
      this.loadNewDetailData(newId);
      if (shareUid && shareUid.length) {
        // 分享用户id
        util.setStorageSync("SHAREUID", shareUid);
      }
    } else {
      util.showToast({ title: "数据维护中,请您稍后再试" });
      setTimeout(function () {
        wx.reLaunch({
          url: "/pages/index/index",
        });
      }, 800);
    }
  },

  onUnload: function () {
    if (this._palette) {
      this._palette = null;
    }
  },
  /**
   * 用户点击右上角分享
   */
  onShareAppMessage: function () {
    const { detailData } = this.data;
    let path = `/pages/newDetail/newDetail?newId=${this.data.newId}`;
    const userInfo = util.getStorageSync("USERINFO");
    if (userInfo && userInfo.userCode && userInfo.userCode.length) {
      // 分享用户id
      path = path + "&shareUid=" + userInfo.userCode;
    }

    let coverImgUrl = "";
    if (detailData.coverImgUrl) {
      coverImgUrl = detailData.coverImgUrl;
    } else if (detailData.imgsUrl.length) {
      coverImgUrl = detailData.imgsUrl[0];
    } else {
      coverImgUrl = "https://static.hoolihome.com/weapp/daily/poster-cover.png";
    }

    let title = "留学daily";
    if (detailData.title) {
      title = detailData.title;
    } else if (detailData.content) {
      title = detailData.content;
    } else {
      title = "留学daily";
    }

    return {
      title: title,
      path: path,
      imageUrl: coverImgUrl,
    };
  },

  /**
   * 页面上拉触底事件的处理函数
   */
  onReachBottom: function () {
    if (!this._isLoad) {
      this.data.page += 1;
      this.loadCommentListData();
    }
  },

  loadNewDetailData() {
    let params = {};
    params.url = api_material_info;
    params.data = {
      id: this.data.newId,
    };
    net.req(params, true).then(
      (data) => {
        this.setData(
          {
            detailData: data,
            totalCount: data.commentNum,
            likeNum: data.likeNum,
          },
          () => {
            this.loadCommentListData();
            this.setStorageHistoryObj();
          }
        );
      },
      (e) => {
        util.showToast({ title: e.msg || "" });
      }
    );
  },

  loadCommentListData() {
    const { commentList, newId, page, limit } = this.data;
    let params = {};
    params.url = api_comment_list;
    params.data = {
      subId: newId,
      page: page,
      limit: limit,
    };
    this._isLoad = true;
    net.req(params, true).then(
      (data) => {
        if (data.list.length) {
          this.setData({
            commentList: commentList.concat(data.list),
          });
          this._isLoad = false;
        } else {
          commentList.length && (this._isLoad = true);
        }
        this.setData({
          isEmpty: !this.data.commentList.length,
        });
      },
      (e) => {
        util.showToast({ title: e.msg || "" });
        this._isLoad = false;
      }
    );
  },

  setStorageHistoryObj() {
    const { newId } = this.data;
    let historyObj = wx.getStorageSync("LOOKHISTORY");
    try {
      historyObj = JSON.parse(historyObj);
    } catch (error) {
      historyObj = {};
    } finally {
      historyObj[newId] = true;
      wx.setStorageSync("LOOKHISTORY", JSON.stringify(historyObj));
    }
  },

  loadedVideoMetaData(res) {
    this.setData({
      videoLoad: true,
    });
  },

  fullscreenVideochange(res) {
    const fullScreen = res.detail.fullScreen;
    this.setData({
      isFullScreen: fullScreen,
    });
  },

  handleLikeAction(e) {
    const { likeNum } = e.detail;
    this.setData({
      likeNum: likeNum,
    });
  },

  onBlur: function (e) {
    this.setData({
      showInput: false,
      inputValue: e.detail.value || "",
    });
  },

  tapReplyAction(e) {
    let replyName = "",
      isAuthor = false;
    if (this.judgeUserLogin()) {
      const { detailData, commentList } = this.data;
      // 判断是否增加一级评论
      if (e.detail.isComment) {
        this._isComment = true;
        replyName = detailData.authorInfo.userName || "";
        isAuthor = true;
      } else {
        this._isComment = false;
        const { currentIndex } = e.currentTarget.dataset;
        this._currentIndex = currentIndex;
        // 判断是评论一级还是二级
        if (e.detail && e.detail.item) {
          const { item } = e.detail;
          this._currentItem = item;
          replyName = item.userInfo.userName;
          isAuthor = !!item.userInfo.isAuthor;
        } else {
          this._currentItem = null;
          const data = commentList[currentIndex];
          replyName = data.userInfo.userName;
          isAuthor = !!data.userInfo.isAuthor;
        }
      }
      this.setData({
        showInput: true,
        replyName: replyName,
        isAuthor: isAuthor,
      });
    }
  },

  tapDeleteAction(e) {
    const { commentList } = this.data;
    let params = {};
    params.url = api_comment_delete;
    params.data = {};
    const { currentIndex } = e.currentTarget.dataset;
    const { item, index } = e.detail;
    // 判断是删除一级还是删除
    let isFrist = false;
    if (item) {
      params.data.commentId = item.id;
      isFrist = false;
    } else {
      isFrist = true;
      const data = commentList[currentIndex];
      data && (params.data.commentId = data.id);
    }
    net.req(params).then((data) => {
      util.showToast({ title: "删除成功!" });
      if (isFrist) {
        commentList.splice(currentIndex, 1);
        this.setData({
          commentList: commentList,
          totalCount: data.commentNum,
          isEmpty: !commentList.length,
        });
      } else {
        let obj = commentList[currentIndex];
        if (obj && obj.replyList && obj.replyList.length) {
          obj && obj.replyList.splice(index, 1);
        }
        this.setData({
          [`commentList[${currentIndex}].replyList`]: obj.replyList,
          totalCount: data.commentNum,
          isEmpty: !commentList.length,
        });
      }
    });
  },
  sendCommentAction(e) {
    if (this._isSend) return;
    if (this.judgeUserLogin()) {
      const { inputValue, commentList } = this.data;
      const { value } = e.detail;
      let params = {};
      params.url = api_comment_add;
      params.data = {
        subId: this.data.newId,
        content: value || inputValue,
      };

      // 判断是否是增加一级评论
      if (!this._isComment) {
        // 判断是评论一级还是二级
        if (this._currentItem) {
          params.data.toId = this._currentItem.id;
        } else {
          const data = commentList[this._currentIndex];
          data && (params.data.toId = data.id);
        }
      }

      this._isSend = true;
      net.req(params).then(
        (data) => {
          // 判断是否是增加一级评论
          if (this._isComment) {
            commentList.unshift(data);
            this.setData({
              commentList: commentList,
              inputValue: "", // 清空输入框
              totalCount: data.commentNum,
              isEmpty: false,
            });
          } else {
            let obj = commentList[this._currentIndex];
            if (obj && obj.replyList && obj.replyList.length) {
              obj && obj.replyList.push(data);
            } else {
              obj &&
                (obj = Object.assign(obj, {
                  replyList: [data],
                }));
            }
            this.setData({
              [`commentList[${this._currentIndex}]`]: obj,
              inputValue: "", // 清空输入框
              totalCount: data.commentNum,
              isEmpty: false,
            });
          }
          this._isSend = false;
        },
        (e) => {
          this._isSend = false;
        }
      );
    }
  },

  judgeUserLogin() {
    const userInfo = util.getStorageSync("USERINFO");
    if (userInfo && userInfo.token) {
      return true;
    } else {
      wx.navigateTo({ url: `/pages/login/login` });
    }
  },

  tapMessageAction(e) {
    if (this._scrollTop) {
      wx.pageScrollTo({
        scrollTop: this._scrollTop,
        duration: 300,
      });
    } else {
      const _this = this;
      wx.createSelectorQuery()
        .select("#contentID")
        .boundingClientRect(function (res) {
          _this._scrollTop = res.height;
          wx.pageScrollTo({
            scrollTop: res.height,
            duration: 300,
          });
        })
        .exec();
    }
  },

  refreshCallback() {
    this.data.shareQRImgSrc = null;
    this.loadNewDetailData();
    this.loadCommentListData();
  },

  getBarcode: function () {
    let { newId, detailData } = this.data;
    const userInfo = util.getStorageSync("USERINFO");
    let shareToken = newId;
    if (userInfo && userInfo.userCode && userInfo.userCode.length) {
      shareToken += userInfo.userCode;
    }
    shareToken =
      shareToken.length > 32 ? shareToken.substring(0, 31) : shareToken; // 做容错判断,超过32位
    let params = {};
    params.url = api_share_qrCode;
    const path = detailData.shareObj
      ? detailData.shareObj.path
      : "pages/newDetail/newDetail";
    params.data = {
      scene: shareToken,
      page: path,
      width: 150,
    };
    net
      .req(params, true)
      .then((data) => {
        const extendObj = {
          type: detailData.type,
          title: detailData.type == 3 ? detailData.content : detailData.title,
          authorInfo: userInfo,
          type: detailData.type,
        };
        let typeText = "正在读这篇文章";
        if (detailData.type === 1) {
          typeText = "正在读这篇文章";
        } else if (detailData.type === 2) {
          typeText = "正在看这个视频";
        } else if (detailData.type === 3) {
          typeText = "正在看这个帖子";
        }
        extendObj.typeText = typeText;
        if (detailData.type == 2) {
          if (detailData.videoCoverImgUrl.length) {
            extendObj.coverImg = detailData.videoCoverImgUrl;
          } else {
            extendObj.coverImg = detailData.coverImgUrl;
          }
          extendObj.videoDuration = detailData.videoDuration;
        } else {
          if (detailData.imgsUrl.length) {
            extendObj.coverImg = detailData.imgsUrl[0];
          } else {
            extendObj.coverImg = detailData.coverImgUrl;
          }
        }

        if (data.qrImg && data.qrImg.length) {
          this.setData(
            {
              isShowQRPoster: true,
              postImgSrc: data.qrImg,
              extendObj: extendObj,
            },
            () => {
              wx.showLoading({
                title: "生成海报中...",
              });
            }
          );
        } else {
          util.showToast({ title: "程序员小哥哥努力开发中..." });
        }
      })
      .catch(() => {
        // this.setData({
        //   postImgSrc: "https://discuz.hoolihome.com/defaults/barcode2.jpg",
        // });
      });
  },
  handleGeneratePoster() {
    const { shareQRImgSrc } = this.data;
    if (shareQRImgSrc) {
      this.setData({
        isShowPostMask: true,
      });
      return;
    } else {
      this.getBarcode();
    }
  },

  posterCallack: function (arr) {
    if (!arr) return;
    let isFirstTop = 0;
    arr.forEach((v, i, a) => {
      let { id, dataset, top } = v;
      if (id.indexOf("image") !== -1) {
        wx.getImageInfo({
          src: dataset.what,
          success: (res) => {
            v.dataset.uri = res.path;
          },
        });
      }
      if (i == 0 && top < 0) {
        isFirstTop = Math.abs(top);
        v.top = 0;
      } else if (isFirstTop) {
        v.top += isFirstTop;
      }
      // 圈子显示三行是,css 设置了top:2000px;所以需要减去2000
      if (top >= 2000) {
        v.top -= 2000;
      }
    });
    if (Array.isArray(arr) && arr.length) {
      this.setData(
        {
          isShowCanvas: true,
          isShowQRPoster: false,
        },
        () => {
          this._palette = new Poster().palette(arr);
          this.setData({
            template: this._palette,
          });
        }
      );
    } else {
      util.showToast({ title: "程序员小哥哥努力开发中..." });
    }
  },

  onImgOK: function (e) {
    if (this.data.shareQRImgSrc) {
      return false;
    }
    const canvasSrc = e.detail.path;
    wx.hideLoading();
    this.setData(
      {
        isShowCanvas: false,
      },
      () => {
        this.setData({
          shareQRImgSrc: canvasSrc,
          isShowPostMask: true,
        });
        this.saveImgAction();
      }
    );
  },

  onImgErr: function () {
    util.showToast({ title: "生成分享海报失败,请您稍后再试..." });
  },

  saveImgAction: function () {
    const _this = this;
    wx.saveImageToPhotosAlbum({
      filePath: this.data.shareQRImgSrc,
      success(res) {
        // wx.showToast({
        //   title: "保存成功",
        //   icon: "none",
        //   duration: 1000,
        // });
      },
      fail() {
        wx.showModal({
          title: "授权失败",
          content: "是否打开小程序设置界面，完成对该小程序授权状态",
          success: function (res) {
            if (res.confirm) {
              wx.openSetting({
                success(res) {},
              });
            }
          },
        });
      },
    });
  },
  postMaskHide: function () {
    this.setData({
      isShowPostMask: false,
    });
  },

  shareQRImgLoad() {
    this.setData({
      shareQRImgLoad: true,
    });
  },

  tapPreviewImage(e) {
    const { detailData } = this.data;
    const { currentItem } = e.currentTarget.dataset;
    wx.previewImage({
      current: currentItem, // 当前显示图片的http链接
      urls: detailData.imgsUrl, // 需要预览的图片http链接列表
    });
  },
});
