const net = require("../../utils/net.js");
const util = require("../../utils/util.js");
const { api_news_list, api_tips_delete } = require("../../utils/api.js");
const app = getApp();

Page({
  /**
   * 页面的初始数据
   */
  data: {
    postList: [],
    page: 1,
    limit: 10,
    scrollH: app.globalData.windowHeight - 60,
    isEmpty: false,
    isEnd: false,
    isRefresh: false,
  },

  /**
   * 生命周期函数--监听页面加载
   */
  onLoad: function (options) {
    const { shareUid } = options;
    // 分享用户id
    if (shareUid && shareUid.length) {
      util.setStorageSync("SHAREUID", shareUid);
    }
    this.getScrollH();
    this.loadPostsData({ isRefresh: true });
  },

  /**
   * 用户点击右上角分享
   */
  onShareAppMessage: function () {
    let path = `/pages/postList/postList`;
    const userInfo = util.getStorageSync("USERINFO");
    if (userInfo && userInfo.userCode && userInfo.userCode.length) {
      // 分享用户id
      path = path + "?shareUid=" + userInfo.userCode;
    }
    return {
      title: "留学daily",
      path: path,
    };
  },

  /**
   * 页面上拉触底事件的处理函数
   */
  scrollToLower: function () {
    if (this._isload) return false;
    this.loadPostsData({
      isRefresh: false,
    });
  },

  getScrollH() {
    const _this = this;
    wx.createSelectorQuery()
      .select("#navBar")
      .boundingClientRect(function (res) {
        const sys = wx.getSystemInfoSync();
        _this.setData({
          scrollH: sys.windowHeight - res.height,
        });
      })
      .exec();
  },

  loadPostsData(obj) {
    const { limit, postList } = this.data;
    let params = {};
    params.url = api_news_list;
    params.data = {
      type: 3,
      limit: limit,
    };
    const len = postList.length;
    if (!obj.isRefresh && len) {
      params.data.lastId = postList[len - 1].id;
    }
    net.req(params).then(
      (data) => {
        if (obj.isRefresh) {
          if (!data.list.length) {
            this.setData({
              isEmpty: true,
            });
          } else {
            this.setData({
              postList: data.list,
              isEnd: data.list.length < limit,
            });
          }
          this.setData({
            isRefresh: false,
          });
          this._isload = false;
          this._refresh = false;
        } else {
          if (data.list.length) {
            this.setData({
              postList: postList.concat(data.list),
              isEnd: data.list.length < limit,
            });
          }
          this._isload = data.list.length < limit;
        }
      },
      (e) => {
        obj.isRefresh ? (this._refresh = false) : (this._isload = false);
      }
    );
  },
  refresherrefresh() {
    if (this._refresh) return;
    this.setData({
      isRefresh: true,
    });
    this.loadPostsData({ isRefresh: true });
  },
  refreshCallback() {
    this.loadPostsData({ isRefresh: true });
  },

  tapDeleteAction(e) {
    const { postList } = this.data;
    const { index } = e.detail;
    let params = {};
    params.url = api_tips_delete;
    params.data = {
      id: postList[index].id,
    };
    net.req(params).then(() => {
      postList.splice(index, 1);
      this.setData({
        postList: postList,
      });
      util.showToast({ title: "删除成功!" });
    });
  },
});
