// pages/tags/tags.js
const net = require("../../utils/net.js");
const { api_topic_list } = require("../../utils/api.js");
const util = require("../../utils/util.js");

Page({
  /**
   * 页面的初始数据
   */
  data: {
    tagsArr: [],
    page: 1,
    limit: 20,
    inputValue: "",
    scrollH: 64,
  },

  /**
   * 生命周期函数--监听页面加载
   */
  onLoad: function () {
    this.loadTagsData({
      isRefresh: true,
    });
    this.bindSearch = util.debounce(this.bindSearch);
  },

  /**
   * 页面上拉触底事件的处理函数
   */
  onReachBottom: function () {
    if (this._isload) {
      return false;
    }
    this.data.page += 1;
    this.loadTagsData({
      isRefresh: false,
    });
  },

  bindSearch: function (e) {
    const { value } = e.detail;
    const keyword = value.trim();
    if (keyword.length) {
      this.data.inputValue = keyword;
      this.data.page = 1;
      this.loadTagsData(
        {
          isRefresh: true,
        },
        keyword
      );
    }
  },

  tapCancelAction() {
    const { inputValue } = this.data;
    if (inputValue.length) {
      this.setData({
        inputValue: "",
      });
      this.loadTagsData({
        isRefresh: true,
      });
    }
  },

  loadTagsData(obj, keyword) {
    const { page, limit, tagsArr } = this.data;
    let params = {};
    params.url = api_topic_list;
    params.data = {
      page: page,
      limit: limit,
    };
    keyword && keyword.length && (params.data.keyword = keyword);
    net.req(params, true).then(
      (data) => {
        if (obj.isRefresh) {
          this.setData({
            tagsArr: data.list,
          });
          this._isload = false;
          this._refresh = false;
        } else {
          if (data.list.length) {
            this.setData({
              tagsArr: tagsArr.concat(data.list),
            });
          }
          this._isload = data.list.length < limit;
        }
      },
      (e) => {
        obj.isRefresh ? (this._refresh = false) : (this._isload = false);
      }
    );
  },

  tapCellAction(e) {
    const { item } = e.currentTarget.dataset;
    const eventChannel = this.getOpenerEventChannel();
    eventChannel && eventChannel.emit("acceptDataFromTagsPage", item);
    wx.navigateBack();
  },
});
